/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.calendar.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for FreeBusyRequest.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Calendar API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class FreeBusyRequest extends GenericJson {

  /**
   * Maximal number of calendars for which FreeBusy information is to be provided. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer calendarExpansionMax;

  /**
   * Maximal number of calendar identifiers to be provided for a single group. Optional. An error
   * will be returned for a group with more members than this value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer groupExpansionMax;

  /**
   * List of calendars and/or groups to query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<FreeBusyRequestItem> items;

  static {
    // hack to force ProGuard to consider FreeBusyRequestItem used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(FreeBusyRequestItem.class);
  }

  /**
   * The end of the interval for the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime timeMax;

  /**
   * The start of the interval for the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime timeMin;

  /**
   * Time zone used in the response. Optional. The default is UTC.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String timeZone;

  /**
   * Maximal number of calendars for which FreeBusy information is to be provided. Optional.
   * The value returned may be {@code null}.
   */
  public Integer getCalendarExpansionMax() {
    return calendarExpansionMax;
  }

  /**
   * Maximal number of calendars for which FreeBusy information is to be provided. Optional.
   * The value set may be {@code null}.
   */
  public FreeBusyRequest setCalendarExpansionMax(Integer calendarExpansionMax) {
    this.calendarExpansionMax = calendarExpansionMax;
    return this;
  }

  /**
   * Maximal number of calendar identifiers to be provided for a single group. Optional. An error
   * will be returned for a group with more members than this value.
   * The value returned may be {@code null}.
   */
  public Integer getGroupExpansionMax() {
    return groupExpansionMax;
  }

  /**
   * Maximal number of calendar identifiers to be provided for a single group. Optional. An error
   * will be returned for a group with more members than this value.
   * The value set may be {@code null}.
   */
  public FreeBusyRequest setGroupExpansionMax(Integer groupExpansionMax) {
    this.groupExpansionMax = groupExpansionMax;
    return this;
  }

  /**
   * List of calendars and/or groups to query.
   * The value returned may be {@code null}.
   */
  public java.util.List<FreeBusyRequestItem> getItems() {
    return items;
  }

  /**
   * List of calendars and/or groups to query.
   * The value set may be {@code null}.
   */
  public FreeBusyRequest setItems(java.util.List<FreeBusyRequestItem> items) {
    this.items = items;
    return this;
  }

  /**
   * The end of the interval for the query.
   * The value returned may be {@code null}.
   */
  public DateTime getTimeMax() {
    return timeMax;
  }

  /**
   * The end of the interval for the query.
   * The value set may be {@code null}.
   */
  public FreeBusyRequest setTimeMax(DateTime timeMax) {
    this.timeMax = timeMax;
    return this;
  }

  /**
   * The start of the interval for the query.
   * The value returned may be {@code null}.
   */
  public DateTime getTimeMin() {
    return timeMin;
  }

  /**
   * The start of the interval for the query.
   * The value set may be {@code null}.
   */
  public FreeBusyRequest setTimeMin(DateTime timeMin) {
    this.timeMin = timeMin;
    return this;
  }

  /**
   * Time zone used in the response. Optional. The default is UTC.
   * The value returned may be {@code null}.
   */
  public String getTimeZone() {
    return timeZone;
  }

  /**
   * Time zone used in the response. Optional. The default is UTC.
   * The value set may be {@code null}.
   */
  public FreeBusyRequest setTimeZone(String timeZone) {
    this.timeZone = timeZone;
    return this;
  }

}
